sequencetools.CyclicMatrix
==========================

.. abjad-lineage:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix

.. autoclass:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.columns
   :noindex:

.. autoattribute:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.rows
   :noindex:

.. autoattribute:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.__eq__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.__ge__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.__getitem__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.__gt__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.__le__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.__lt__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.__ne__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.__repr__
   :noindex:
